@@ -13,6 +13,7 @@ from couchbase.cluster import Cluster
 import couchbase.subdocument as SD
 from couchbase.exceptions import (CouchbaseException, QueryIndexNotFoundException, DocumentNotFoundException, DocumentExistsException, QueryIndexAlreadyExistsException)
 from couchbase.options import (QueryOptions, LockMode, ClusterOptions, TLSVerifyMode, WaitUntilReadyOptions)
+from couchbase.management.options import GetAllQueryIndexOptions
 from couchbase.diagnostics import ServiceType
 
 JSONType = Union[str, int, float, bool, None, Dict[str, Any], List[Any]]
@@ -102,6 +103,16 @@ class CBConnect(CBSession):
         except Exception as err:
             raise BucketWaitException(f"bucket_wait: error: {err}")
 
+    def has_primary_index(self):
+        qim = self._cluster.query_indexes()
+        index_get_options = GetAllQueryIndexOptions(scope_name=self._scope_name, collection_name=self._collection_name)
+        indexes = qim.get_all_indexes(self._bucket.name, index_get_options)
+        index_names = list(map(lambda i: i.name, [index for index in indexes]))
+        if '#primary' in index_names:
+            return True
+        else:
+            return False
+
     @retry()
     def cb_get(self, key: Union[int, str]):
         try:
